import requests
from bs4 import BeautifulSoup

def get_wiki_random():
    """
    - Get random article from Wikipedia. 

    Returns:
        title and url
    """
    url = requests.get("https://en.wikipedia.org/wiki/Special:Random")
    soup = BeautifulSoup(url.content, "html.parser")
    title = soup.find(class_="firstHeading").text

    url = "https://en.wikipedia.org/wiki/%s" % title

    return title,url
    


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['wiki_random']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2', 'requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'wiki-random',
    'version': '0.1.4',
    'description': 'get random article from wikipedia',
    'long_description': '',
    'author': 'Igor Moryto',
    'author_email': '56959606+Ezykill@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Ezykill/wiki_random',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
